package com.dcs.hnyz.service;

import java.util.List;
import java.util.Map;

import com.dcs.hnyz.domain.PageControl;

/**
 * 页面管理Service接口
 * 
 * @author hmy
 * @date 2025-07-25
 */
public interface IPageControlService 
{
    /**
     * 查询页面管理
     * 
     * @param pageId 页面管理主键
     * @return 页面管理
     */
    public PageControl selectPageControlByPageId(Long pageId);

    /**
     * 查询页面管理列表
     * 
     * @param pageControl 页面管理
     * @return 页面管理集合
     */
    public List<PageControl> selectPageControlList(PageControl pageControl);

    /**
     * 新增页面管理
     * 
     * @param pageControl 页面管理
     * @return 结果
     */
    public int insertPageControl(PageControl pageControl);

    /**
     * 修改页面管理
     * 
     * @param pageControl 页面管理
     * @return 结果
     */
    public int updatePageControl(PageControl pageControl);

    /**
     * 批量删除页面管理
     * 
     * @param pageIds 需要删除的页面管理主键集合
     * @return 结果
     */
    public int deletePageControlByPageIds(Long[] pageIds);

    /**
     * 删除页面管理信息
     * 
     * @param pageId 页面管理主键
     * @return 结果
     */
    public int deletePageControlByPageId(Long pageId);

    /**
     * 获取页面名称map
     */
    Map<Long, String> getPageNameMap();

    /**
     * 根据设备id获取对应页面列表
     * @param equipmentId
     * @return
     */
    List<PageControl> getPageList(Long equipmentId);

    /**
     * 根据页面标识获取页面信息
     * @param pageCode
     * @return
     */
    PageControl getPageByCode(String pageCode);
}
